@@ -3,6 +3,7 @@ import requests_cache
 import urllib
 import re
 
+from requests.adapters import HTTPAdapter, Retry
 from squad_client import logging
 from squad_client.version import __min_squad_version__ as min_squad_version
 
@@ -48,6 +49,7 @@ class SquadApi:
     token = None
     headers = None
     version = None
+    session = None
 
     @staticmethod
     def configure(url, token=None, cache=0):
@@ -89,6 +91,20 @@ class SquadApi:
     def delete(endpoint, params={}, data={}):
         return SquadApi.__request__('DELETE', endpoint, params=params, data=data)
 
+    @staticmethod
+    def get_session():
+        if SquadApi.session is None:
+            retry_strategy = Retry(
+                total=5,
+                backoff_factor=1,
+                status_forcelist=[429, 500, 502, 503, 504],
+                allowed_methods=["HEAD", "GET", "PUT", "DELETE", "OPTIONS", "TRACE"])
+            adapter = HTTPAdapter(max_retries=retry_strategy)
+            SquadApi.session = requests.Session()
+            SquadApi.session.mount('http://', adapter)
+            SquadApi.session.mount('https://', adapter)
+        return SquadApi.session
+
     @staticmethod
     def __request__(method, endpoint, **kwargs):
         if SquadApi.url is None:
@@ -117,7 +133,9 @@ class SquadApi:
             kwargs['headers'] = SquadApi.headers
 
         try:
-            response = requests.request(method, url, auth=NullAuth(), **kwargs)
+            session = SquadApi.get_session()
+            response = session.request(method, url, auth=NullAuth(), **kwargs)
+
             if response.status_code == 401:
                 msg = 'Unauthorized access to "%s"' % url
                 # logger.error(msg)
